Formatted_MUTimpactMatrix: The output of 'mts_formatMatrix()' function for an example...

Formatted_MUTimpactMatrixR Documentation

The output of mts_formatMatrix() function for an example dataset.

Description

List of 23 dataframes where each element corresponds to a gene. The mutation impact data per sample is given for each gene, correctly formatted for analysis with the mts_patternDetection function.

Usage

data("Formatted_MUTimpactMatrix")

Format

A data frame with 3 columns: 'Samples', 'Impact' and 'impact Group'.

Examples

data(Formatted_MUTimpactMatrix)

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.