MUT_impactMatrix: Example mutation impact matrix

MUT_impactMatrixR Documentation

Example mutation impact matrix

Description

A binary/numeric matrix in gene by sample format, where row names correspond to genes (or probesets) and columns are sample names. The matrix cells must have values of '1' or '2' to represent mutation impact (1 for HIGH impact, 2 for LOW impact). This matrix has been adapted from DepMap (Tsherniak et al. 2017), the numeric values in the matrix were generated pseudo-randomly.

Usage

data("MUT_impactMatrix")

Format

A data frame with 23 observations (genes) on 26 variables (cell lines).

DepMap 2024Q2 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.25452/figshare.plus.25880521.v1")}

References

Tsherniak A., Vazquez F., Montgomery P.G., Weir B.A., Kryukov G., Cowley G.S., Gill S., Harrington W.F., Pantel S., Krill-Burger J.M. et al. . Defining a cancer dependency map. Cell. 2017; 170:564-576. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.cell.2017.06.010")}

Examples

data(MUT_impactMatrix)
MUT_impactMatrix[1:10,1:10]

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.