mRes: Example results for the 'mts_Mutation' function.

mResR Documentation

Example results for the mts_Mutation function.

Description

A data frame containing example predicted gene dependencies produced by the mts_Mutation function (which takes as input gene expression and mutation data).

Usage

data("mRes")

Format

A data frame with 3039 observations on the following 5 variables.

mRNA_gene

a character vector

mutation_gene

a character vector

tissue

a character vector

chiSqPvalue

a numeric vector

mutation_per_mode

a character vector

References

Wappett et al. (2021) [Nucleic Acids Research 49, W613-W618] \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/nar/gkab338")}

Examples

data(mRes)
mRes[1:10,]

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.