mixModelClusters_depMapCRISPR: Clusters of samples (cell lines) from the...

mixModelClusters_depMapCRISPRR Documentation

Clusters of samples (cell lines) from the mts_mixModelCluster function for a small dataset of DepMap CRISPR scores.

Description

List of 5 data frames where each element corresponds to a gene.

Usage

data("mixModelClusters_depMapCRISPR")

Format

Each data frame in the list has 3 columns: gene ID, log2 gene expression and cluster assignment. Also provides an example of a gene, EIF1AX, that was not able to receive cluster assignments.

Derived from analysis of data taken from DepMap 2024Q2 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.25452/figshare.plus.25880521.v1")}

References

Tsherniak A., Vazquez F., Montgomery P.G., Weir B.A., Kryukov G., Cowley G.S., Gill S., Harrington W.F., Pantel S., Krill-Burger J.M. et al. . Defining a cancer dependency map. Cell. 2017; 170:564-576. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.cell.2017.06.010")}

Examples

data(mixModelClusters_depMapCRISPR)

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.