mts_ClusterAvg: Determine average CRISPR score values for gene expression...

mts_clusterAvgR Documentation

Determine average CRISPR score values for gene expression clusters

Description

MultiSEp applies regularised Gaussian Mixture Modelling (GMM) with expectation-maximisation to discover clusters, or modes, from functional genomics data; for example gene expression (such as RNA-seq), or CRISPR scores. Cardinality (the number of clusters) is determined by regularisation with Bayesian Information Criterion, considering at least two and up to five clusters. Each sample is assigned a probability of belonging to each cluster by MultiSEp, for example some samples may be positioned in a region of overlap between two clusters formed from the mixture of Gaussians used to model the distribution of the functional genomics data. The mts_clusterAvg function generates Gaussian mixture models for gene expression data, assigning samples to clusters for each gene. Subsequently, the average CRISPR score value is calculated per cluster of samples for all of the genes with CRISPR data. Accordingly, each gene with expression data is paired with all of the genes with CRISPR data across the samples analysed and these results provide the basis for quantification of the differences in CRISPR scores between gene expression clusters in downstream functions.

Usage

mts_clusterAvg(exprsMatrix, crisprMatrix, cores)

Arguments

exprsMatrix

A log2 gene expression matrix in gene by sample format, where rownames correspond to genes (or probesets) and colnames correspond to sample names.

crisprMatrix

A crispr score matrix in gene by sample format, where rownames correspond to genes (or guide RNA's) and colnames correspond to sample names. The score should be derived from a pooled or arrayed CRISPR screen where negative scores correspond to dependency and positive scores correspond to outgrowth.

cores

The number of compute cores to use. Defaults to 1.

Value

A list of sublists corresponding to each gene in the exprsMatrix object. Each sublist has the following components:

AverageCrisprScore

The average CRISPR score of each gene in the crisprMatrix object in each cluster assigned by Multisep to each gene in the exprsMatrix object. Column headings 'Cluster 1', 'Cluster 2' etc.

Sample

The sample name, for example cell line identifiers.

Log2 Expression

The log2 gene expression value for the sample.

Expression Cluster

The cluster assigned to the sample by Multisep

References

Wappett et al. (2021) [Nucleic Acids Research 49, W613-W618] \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/nar/gkab338")}

See Also

mts_plotCRISPRGeneCluster, mts_Crispr, mts_CrisprTS, mts_InducedDependency

Examples

data(depMapXPR_subset)
data(depMapCRISPRscores_subset)

mR1 <- mts_clusterAvg(
  exprsMatrix=depMapXPR_subset[1,],
  crisprMatrix=depMapCRISPRscores_subset[1:10],
  cores=1
)


MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.