mts_Crispr: Investigate Gene Dependency Relationships with CRISPR and...

View source: R/mts_Crispr.R

mts_CrisprR Documentation

Investigate Gene Dependency Relationships with CRISPR and gene expression data

Description

Performs statistical evaluation of gene dependency relationships for CRISPR scores between consecutive mRNA expression clusters.

Usage

mts_Crispr(resultList = resultList, exprsMatrix = exprsMatrix,
crisprMatrix = crisprMatrix, fcVal = fcVal, pVal = pVal, cores = cores)

Arguments

resultList

A result list object produced by the mts_clusterAvg function.

exprsMatrix

A log2 gene expression matrix in gene by sample format, where rownames correspond to genes (or probesets) and colnames correspond to sample names.

crisprMatrix

A crispr score matrix in gene by sample format, where rownames correspond to genes (or guide RNA's) and colnames correspond to sample names. The score should be derived from a pooled or arrayed CRISPR screen where negative scores correspond to dependency and positive scores correspond to outgrowth.

fcVal

A log 2 fold change value filter. Defaults to -0.1.

pVal

A p value filter. Defaults to 0.1.

cores

The number of compute cores to use. Defaults to 1.

Details

Gene expression clusters enable partitioning of effect scores from CRISPR screen data, and therefore may reveal pairwise gene dependencies. Statistical evaluation of dependency relationships is carried out by calculating a log2 fold-change and two-tailed T-test p-value between the CRISPR scores for each consecutive pair of mRNA expression clusters. The user can define the fold change (default:-0.1) and p-value (default: 0.1) cutoff values. Q-values are also calculated; we strongly recommend taking the q-values as a baseline for determining statistical significance, indeed it is crucially important to correct for multiple hypothesis testing to ensure the statistical validity of results.

Value

A data frame containing the significantly enriched gene expression and CRISPR gene pair results. The data frame contains the following columns:

mrna_gene

Gene id of the gene expression gene

crispr_gene

Gene id of the crispr gene

num_modes

Number of gene expression clusters

nMode1-5

Number of cell lines in each gene expression cluster

mMode1-5

Mean CRISPR score of the crispr gene in each gene expression cluster

shift2_1

Fold-change of CRISPR scores between expression modes 2 and 1

shift3_2

Fold-change of CRISPR scores between expression modes 3 and 2. NA if mRNA gene has 2 gene expression clusters

shift4_3

Fold-change of CRISPR scores between expression modes 4 and 3. NA if mRNA gene has 2 or 3 gene expression clusters

shift5_4

Fold-change of CRISPR scores between expression modes 5 and 4. NA if mRNA gene has 2,3 or 4 gene expression clusters

pvalue2_1

P-value of CRISPR scores between expression modes 2 and 1

pvalue3_2

P-value of CRISPR scores between expression modes 3 and 2. NA if mRNA gene has 2 gene expression clusters

pvalue4_3

P-value of CRISPR scores between expression modes 4 and 3. NA if mRNA gene has 2 or 3 gene expression clusters

pvalue5_4

P-value of CRISPR scores between expression modes 5 and 4. NA if mRNA gene has 2,3 or 4 gene expression clusters

qvalue2_1

Q-value of CRISPR scores between expression modes 2 and 1

qvalue3_2

Q-value of CRISPR scores between expression modes 3 and 2. NA if mRNA gene has 2 gene expression clusters

qvalue4_3

Q-value of CRISPR scores between expression modes 4 and 3. NA if mRNA gene has 2 or 3 gene expression clusters

qvalue5_4

Q-value of CRISPR scores between expression modes 5 and 4. NA if mRNA gene has 2,3 or 4 gene expression clusters

See Also

mts_clusterAvg

Examples


data(depMapXPR_subset)
data(depMapCRISPRscores_subset)
data(multisepList)

resultListSmall <- lapply(multisepList["DNAJC15"], function(g) {
    keep <- intersect(rownames(g[[1]]), rownames(depMapCRISPRscores_subset))
    g[[1]] <- g[[1]][keep, , drop = FALSE]
    g
  })

mCrisprOut <- mts_Crispr(
  resultList = resultListSmall,
  exprsMatrix = depMapXPR_subset, 
  crisprMatrix = depMapCRISPRscores_subset
)


MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.