mts_CrisprTS: Predict tissue-specific gene dependency relationships,...

View source: R/mts_CrisprTS.R

mts_CrisprTSR Documentation

Predict tissue-specific gene dependency relationships, evaluating differences in CRISPR scores for gene A between expression clusters for gene B (SynLeGG).

Description

Subsets the output from the mts_Crispr function according to tissue type and performs the analysis again in a tissue specific manner. Running with negative fold-change values (<0) allows prediction of synthetic lethal relationships, specifying positive fold-change values (>0) corresponds to 'induced dependency' relationships.

Usage

mts_CrisprTS(resultList = resultList, crisprMatrix = crisprMatrix, fcVal = fcVal, 
pVal = pVal, cores = cores, tissueMatrix = tissueMatrix, allDisRes = allDisRes)

Arguments

resultList

A result list object produced by the mts_clusterAvg function.

crisprMatrix

A crispr score matrix in gene by sample format, where rownames correspond to genes (or guide RNA's) and colnames correspond to sample names. The score should be derived from a pooled or arrayed CRISPR screen where negative scores correspond to dependency and positive scores correspond to outgrowth.

fcVal

The log2 fold-change threshold, default is -0.1.

pVal

The p-value threshold, default is 0.1.

cores

The number of compute cores to use, defaults to 1.

tissueMatrix

A data frame containing 2 columns where column 1 is the sample id and column 2 is the tissue id.

allDisRes

A result list object produced by the mts_Crispr function.

Value

A data frame containing the significantly enriched gene expression and CRISPR gene pair results. The data frame contains the following columns:

mrna_gene

Gene id of the gene expression gene

crispr_gene

Gene id of the crispr gene

tissue

Tissue ID of the gene pair comparison

num_modes

Number of gene expression clusters

nMode1-5

Number of cell lines in each gene expression cluster

mMode1-5

Mean CRISPR score of the crispr gene in each gene expression cluster

shift2_1

Fold-change of CRISPR scores between expression modes 2 and 1

shift3_2

Fold-change of CRISPR scores between expression modes 3 and 2. NA if mRNA gene has 2 gene expression clusters

shift4_3

Fold-change of CRISPR scores between expression modes 4 and 3. NA if mRNA gene has 2 or 3 gene expression clusters

shift5_4

Fold-change of CRISPR scores between expression modes 5 and 4. NA if mRNA gene has 2,3 or 4 gene expression clusters

pvalue2_1

P-value of CRISPR scores between expression modes 2 and 1

pvalue3_2

P-value of CRISPR scores between expression modes 3 and 2. NA if mRNA gene has 2 gene expression clusters

pvalue4_3

P-value of CRISPR scores between expression modes 4 and 3. NA if mRNA gene has 2 or 3 gene expression clusters

pvalue5_4

P-value of CRISPR scores between expression modes 5 and 4. NA if mRNA gene has 2,3 or 4 gene expression clusters

qvalue2_1

Q-value of CRISPR scores between expression modes 2 and 1

qvalue3_2

Q-value of CRISPR scores between expression modes 3 and 2. NA if mRNA gene has 2 gene expression clusters

qvalue4_3

Q-value of CRISPR scores between expression modes 4 and 3. NA if mRNA gene has 2 or 3 gene expression clusters

qvalue5_4

Q-value of CRISPR scores between expression modes 5 and 4. NA if mRNA gene has 2,3 or 4 gene expression clusters

References

Wappett et al. (2021) [Nucleic Acids Research 49, W613-W618] \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/nar/gkab338")}

Examples

data(depMapCRISPRscores_subset)
data(depMapTissue_subset)
data(multisepList)
data(multisepCrisprList)
allDis <- multisepCrisprList[multisepCrisprList$crispr_gene %in%
                               rownames(depMapCRISPRscores_subset), ][1:15, ]

mCrisprTS <- mts_CrisprTS(
  resultList = multisepList,
  crisprMatrix = depMapCRISPRscores_subset, 
  tissueMatrix = depMapTissue_subset,
  fcVal = -0.1, 
  pVal = 0.25, 
  allDisRes = allDis)

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.