mts_GeneDepMutation: Mutation vs gene expression gene-dependency prediction

View source: R/mts_GeneDepMutation.R

mts_GeneDepMutationR Documentation

Mutation vs gene expression gene-dependency prediction

Description

Run the MultiSEp mutation gene-dependency pipeline, with tissue data. As a minimum an expression matrix, mutation matrix and a tissue matrix must be provided (please see details below).

Usage

mts_GeneDepMutation(exprsMatrix = exprsMatrix, mutMatrix= mutMatrix,
cores = cores, pVal = pVal, tissueMatrix = tissueMatrix)

Arguments

exprsMatrix

Log2 gene expression matrix in a gene by sample format where row names are genes and the column names are samples.

mutMatrix

A mutation score matrix in gene by sample format, where row names correspond to genes and column names correspond to sample names. The value should be either 'WT' or a mutation detail (e.g. amino acid change or coding sequence change). For example, please see the depMapMUT_subset object supplied with this package.

cores

The number of compute cores to use, default is 1.

pVal

A p value filter, default is 0.1.

tissueMatrix

Matrix of two columns where column 1 is a sample ID and column 2 is a tissue ID.

Value

A data frame containing the results of MultiSEp analysis of mutations by gene expression clusters, with the following columns:

mrna_gene

Identifier of the gene expression gene

mutation_gene

Identifier of the mutation gene

tissue

Description of the tissue(s) evaluated

chiSqPvalue

p-value from chi-squared test, assessing the distribution of mutation classes across the gene expression clusters

mutation_per_mode

Total number of mutated samples in the multisep gene expression cluster (or 'mode'), for each mutation_gene.

Examples

data(depMapXPR_subset)
data(depMapMUT_subset)
data(depMapTissue_subset)

mtsGeneDepMutResults <- mts_GeneDepMutation(
  exprsMatrix=depMapXPR_subset[1,],
  tissueMatrix = depMapTissue_subset,
  mutMatrix = depMapMUT_subset[1:2, ], pVal=0.1)

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.