mts_InducedDependency: Predict 'induced dependency' relationships, evaluating...

View source: R/mts_inducedDependency.R

mts_InducedDependencyR Documentation

Predict 'induced dependency' relationships, evaluating differences in CRISPR scores for gene A between expression clusters for gene B

Description

Gene expression clusters enable partitioning of effect scores from CRISPR screen data, and therefore may reveal pairwise gene dependencies. mts_InducedDependency performs statistical evaluation of induced dependency relationships (enrichment) by calculating a log2 fold-change and two-tailed T-test p-value between the CRISPR scores for each consecutive pair of mRNA expression clusters. 'Induced dependency' relationships in this function are defined by lower CRISPR scores (corresponding to reduced cell survival/growth) with higher gene expression values; corresponding to filtering by positive fold-change values (>0). Q-values are also calculated (using false discovery rate correction). We strongly recommend taking the q-values as a baseline for determining statistical significance, indeed it is crucially important to correct for multiple hypothesis testing to ensure the statistical validity of results.

Usage

mts_InducedDependency(resultList = resultList, exprsMatrix = exprsMatrix,
crisprMatrix = crisprMatrix, fcVal = fcVal, pVal = pVal, cores = cores)

Arguments

resultList

A result list object produced by the mts_clusterAvg function.

exprsMatrix

A log2 gene expression matrix in gene by sample format, where row names correspond to genes (or probesets) and column names correspond to sample names.

crisprMatrix

A crispr score matrix in gene by sample format, where row names correspond to genes (or guide RNAs) and column names correspond to sample names. The score should be derived from a pooled or arrayed CRISPR screen where negative scores correspond to dependency (e.g. cell death/stasis) and positive scores correspond to outgrowth.

fcVal

The log2 fold-change threshold, defaults to 0.1. Please note that positive fold-change values (>0) should be given for assessment of induced dependency relationships.

pVal

The p-value threshold, defaults to 0.1.

cores

The number of compute cores to use, defaults to 1.

Details

Similar to the methodology applied for CRISPR analysis in the www.overton-lab.uk/synlegg resource (Wappett et al. 2021); developments include an improved approach for discovery of the gene expression clusters.

Value

A data frame containing results for gene expression and CRISPR gene pairs that pass the p-value and log2 fold-change threshold values used. The data frame contains the following columns:

mrna_gene

Identifier of the gene expression gene

crispr_gene

Identifier of the CRISPR gene

num_modes

Number of gene expression clusters

nMode1-5

Number of cell lines in each gene expression cluster

mMode1-5

Mean CRISPR score of the CRISPR gene in each gene expression cluster

shift2_1

Fold-change of CRISPR scores between expression modes (clusters) 2 and 1

shift3_2

Fold-change of CRISPR scores between expression modes (clusters) 3 and 2. NA if mRNA gene has 2 gene expression clusters

shift4_3

Fold-change of CRISPR scores between expression modes (clusters) 4 and 3. NA if mRNA gene has 2 or 3 gene expression clusters

shift5_4

Fold-change of CRISPR scores between expression modes (clusters) 5 and 4. NA if mRNA gene has 2,3 or 4 gene expression clusters

pvalue2_1

P-value of CRISPR scores between expression modes (clusters) 2 and 1

pvalue3_2

P-value of CRISPR scores between expression modes (clusters) 3 and 2. NA if mRNA gene has 2 gene expression clusters

pvalue4_3

P-value of CRISPR scores between expression modes (clusters) 4 and 3. NA if mRNA gene has 2 or 3 gene expression clusters

pvalue5_4

P-value of CRISPR scores between expression modes (clusters) 5 and 4. NA if mRNA gene has 2,3 or 4 gene expression clusters

qvalue2_1

Q-value of CRISPR scores between expression modes (clusters) 2 and 1

qvalue3_2

Q-value of CRISPR scores between expression modes (clusters) 3 and 2. NA if mRNA gene has 2 gene expression clusters

qvalue4_3

Q-value of CRISPR scores between expression modes (clusters) 4 and 3. NA if mRNA gene has 2 or 3 gene expression clusters

qvalue5_4

Q-value of CRISPR scores between expression modes (clusters) 5 and 4. NA if mRNA gene has 2,3 or 4 gene expression clusters

References

Wappett et al. (2021) [Nucleic Acids Research 49, W613-W618] \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/nar/gkab338")}

See Also

mts_clusterAvg

Examples



data(depMapXPR_subset)
data(depMapCRISPRscores_subset)
data(multisepList)

resultListSmall <- lapply(multisepList["DNAJC15"], function(g) {
    keep <- intersect(rownames(g[[1]]), rownames(depMapCRISPRscores_subset))
    g[[1]] <- g[[1]][keep, , drop = FALSE]
    g
  })

mIDOut <-  mts_InducedDependency(
    resultList   = resultListSmall,
    exprsMatrix  = depMapXPR_subset,
    crisprMatrix = depMapCRISPRscores_subset
  )



MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.