mts_pairwiseExpressionPlot: Visualise pairwise gene expression data with MultiSEp cluster...

View source: R/mts_pairwiseExpressionPlot.R

mts_pairwiseExpressionPlotR Documentation

Visualise pairwise gene expression data with MultiSEp cluster boundaries.

Description

Produces a scatterplot of two selected genes on the x and y axis, the boundaries between MultiSEp clusters are shown as blue lines.

Usage

mts_pairwiseExpressionPlot(exprsMatrix, gene1, gene2)

Arguments

exprsMatrix

Log2 gene expression matrix in a gene by sample format where rownames are genes and the column names are samples.

gene1

User specified gene 1. Must match a gene in the exprsMatrix.

gene2

User specified gene 2. Must match a gene in the exprsMatrix.

Value

Produces a scatter plot (base R graphics) of the two genes' log2 expression, with mixture-model cluster boundaries drawn as reference lines.

Examples

data(depMapXPR_subset)
mts_pairwiseExpressionPlot(exprsMatrix = depMapXPR_subset, gene1 = "STX2", gene2="VRK2")

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.