mts_plotMutation: Visualise clusters for one gene with the mutation status of...

View source: R/mts_plotMutation.R

mts_plotMutationR Documentation

Visualise clusters for one gene with the mutation status of another gene.

Description

Produces boxplots to visualise mutational status for clusters produced by Gaussian Mixture Modelling, for example derived from transcriptome data.

Usage

mts_plotMutation(resultList=resultList, mrna_gene = mrna_gene, mut_gene = mut_gene, 
mutMatrix = mutMatrix, tissueMatrix = tissueMatrix, diseaseFilter = diseaseFilter)

Arguments

resultList

A result list object produced by the mts_mixModelCluster function.

mrna_gene

User specified mRNA gene, must match a gene in the clusters.

mut_gene

User specified mutation gene. Must match a gene in the specified mutation matrix.

mutMatrix

A mutation score matrix in gene by sample format, where rownames correspond to genes and colnames correspond to sample names. The value should be either 'WT' or a mutation detail (e.g. amino acid change or coding sequence change).

tissueMatrix

Matrix of two columns where column 1 is a sample ID and column 2 is a tissue ID.

diseaseFilter

User specified tissue filter. Defaults to all.

Value

A ggplot object, which can be printed or saved with ggsave. The plot is a boxplot of mrna_gene log2 expression, split by its expression clusters, with data points coloured by the mutation status ("WT" or mutated) of mut_gene; optionally restricted to a single tissue when diseaseFilter is supplied.

See Also

mts_mixModelCluster

Examples

data(depMapXPR_subset)
data(depMapMUT_subset)
data(depMapTissue_subset)

mixModelClusters <- mts_mixModelCluster(dataMatrix = depMapXPR_subset[1:2,])

mts_plotMutation(
  resultList= mixModelClusters,
  mrna_gene = "EIF1AY", 
  mut_gene = "TP53",
  mutMatrix = depMapMUT_subset, 
  tissueMatrix = depMapTissue_subset, 
  diseaseFilter = "Pancreatic Cancer")

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.