mts_targetCoverageFromMutations: Predict the therapeutic population coverage achieved by...

View source: R/mts_targetCoverageFromMutations.R

mts_targetCoverageFromMutationsR Documentation

Predict the therapeutic population coverage achieved by inhibition of a candidate target gene

Description

This function predicts the therapeutic population coverage achieved by inhibiting each gene in the supplied network of (predicted) synthetic lethal (SL) relationships. A patient with inactivating mutations in partner genes of the candidate target gene is predicted to benefit from inhibition of the target gene because the candidate SL relationship implies that cell death will be caused by inactivation of both genes (one by mutation and one by chemical inhibition). This function can take as input a dataframe of gene pairs (edgeData) or the output from the mts_Mutation() function, both cases also require mutation calls as input.

Usage

  mts_targetCoverageFromMutations(
  mutData, 
  edgeData, 
  rowNum = nrow(edgeData),
  cores
)

Arguments

mutData

A mutation score matrix in gene by sample format, where rownames correspond to genes and colnames correspond to sample names. The value should be either "WT" or a mutation annotation (e.g. amino acid change or coding sequence change). The mutations are used to evaluate population coverage.

edgeData

A dataframe of (predicted) synthetic lethal gene pairs (edges), where gene1 is in column1 and gene2 is in column2. Alternatively, a data frame containing results from the mts_Mutation function.

rowNum

The number of gene pairs from edgeData to include in the network used for the population coverage analysis. If set to a value lower than the supplied network (edgeData), the first n edges are taken (i.e. [1:rowNum]). Defaults to nrow(edgeData).

cores

The number of compute cores to use. Defaults to 1.

Value

A data frame containing the following columns:

Gene

Candidate drug target gene.

NeighbourCount

The number of network neighbours

NumSamplesWithMutation

Number of samples with mutation(s) in any of the neighbour genes.

NeighbourMutationFrequency

The proportion of samples with one or more mutations in any of the neighbour genes.

NeighbourGenes

Identifiers of the neighbouring genes.

MutatedSamples

Identifiers of the samples with mutations

Examples

data(depMapMUT_subset)
data(mRes)
# An example on the first 5 edges (runs quickly):
TpopCoverage_test <- mts_targetCoverageFromMutations(
  mutData=depMapMUT_subset, 
  edgeData=mRes,
  rowNum=5,
  cores=1
)

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.