multisepList: Example results from mts_clusterAvg()

multisepListR Documentation

Example results from mts_clusterAvg()

Description

mts_clusterAvg() produces a list of sublists corresponding to each gene in the input exprsMatrix object. Each sublist has the following components:

Usage

data("multisepList")

Format

A named list containing ten genes, each gene's element is an unnamed list with two components as follows:

Average CRISPR Scores: The average CRISPR score of each gene in the crisprMatrix object in each cluster assigned by multisep to each gene in the exprsMatrix object.

Sample to Cluster map: The log2 gene expression value for each sample and the associated multisep cluster assignment.

Derived from analysis of DepMap 2024Q2 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.25452/figshare.plus.25880521.v1")}

References

Tsherniak A., Vazquez F., Montgomery P.G., Weir B.A., Kryukov G., Cowley G.S., Gill S., Harrington W.F., Pantel S., Krill-Burger J.M. et al. . Defining a cancer dependency map. Cell. 2017; 170:564-576. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.cell.2017.06.010")}

See Also

mts_clusterAvg

Examples

data(multisepList)
multisepList[[1]][[2]][1:10,]

MultiSEp documentation built on Aug. 27, 2026, 5:07 p.m.