| Formatted_MUTimpactMatrix | R Documentation |
mts_formatMatrix() function for an example dataset.
List of 23 dataframes where each element corresponds to a gene. The mutation impact data per sample is given for each gene, correctly formatted for analysis with the mts_patternDetection function.
data("Formatted_MUTimpactMatrix")
A data frame with 3 columns: 'Samples', 'Impact' and 'impact Group'.
data(Formatted_MUTimpactMatrix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.