| mRes | R Documentation |
mts_Mutation function.
A data frame containing example predicted gene dependencies produced by the mts_Mutation function (which takes as input gene expression and mutation data).
data("mRes")
A data frame with 3039 observations on the following 5 variables.
mRNA_genea character vector
mutation_genea character vector
tissuea character vector
chiSqPvaluea numeric vector
mutation_per_modea character vector
Wappett et al. (2021) [Nucleic Acids Research 49, W613-W618] \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/nar/gkab338")}
data(mRes)
mRes[1:10,]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.