View source: R/mts_GeneDepCrispr.R
| mts_GeneDepCrispr | R Documentation |
Run the CRISPR and expression gene-dependency pipeline, optionally with tissue data. Minimally, an expression matrix and a CRISPR matrix must be provided.
mts_GeneDepCrispr(exprsMatrix = exprsMatrix, crisprMatrix = crisprMatrix,
cores = cores, fcVal = fcVal, pVal = pVal, tissueMatrix = tissueMatrix)
exprsMatrix |
Log2 gene expression matrix in a gene by sample format where rownames are genes and the column names are samples. |
crisprMatrix |
Log2 crispr score matrix in a gene by sample format where rownames are genes and the column names are samples. |
cores |
The number of compute cores to use, default is 1. |
fcVal |
A log 2 fold change value filter, default is -0.1. Running with negative fold-change values (<0) allows prediction of synthetic lethal relationships, specifying positive fold-change values (>0) corresponds to 'induced dependency' relationships. |
pVal |
A p value filter, default is 0.1. |
tissueMatrix |
Matrix of two columns where column 1 is a sample ID and column 2 is a tissue ID. |
A list containing up to two tables:
CRISPR_Results |
Cluster assignment table output from the |
CRISPR_TS_Results |
Output from the |
data(depMapCRISPRscores_subset)
data(depMapXPR_subset)
data(depMapTissue_subset)
exprsSub <- depMapXPR_subset["PCYT1B",]
crisprSub <- depMapCRISPRscores_subset["PCYT1A",]
mts_GeneDepCrispr(
exprsMatrix = exprsSub, crisprMatrix = crisprSub,
cores = 1, fcVal = -0.5, pVal = 0.25, tissueMatrix = depMapTissue_subset)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.