View source: R/mts_GeneDepID.R
| mts_GeneDepID | R Documentation |
Run the MultiSEp CRISPR vs gene expression induced dependency pipeline, optionally with tissue data. Minimally, a gene expression matrix and a CRISPR matrix must be provided.
mts_GeneDepID(exprsMatrix = exprsMatrix, crisprMatrix = crisprMatrix,
cores = cores, fcVal = fcVal, pVal = pVal, tissueMatrix = tissueMatrix)
exprsMatrix |
Log2 gene expression matrix in a gene by sample format where rownames are genes and the column names are samples. |
crisprMatrix |
Log2 CRISPR score matrix in a gene by sample format where rownames are genes and the column names are samples. |
cores |
The number of compute cores to use, defaults to 1. |
fcVal |
A log 2 fold change value filter, defaults to 0.1 (positive fold-change values are expected to reflect induced dependency relationships). |
pVal |
A p value filter, defaults to 0.1. |
tissueMatrix |
Matrix with two columns where column 1 is a sample ID and column 2 is a tissue ID. |
A list containing up to 2 tables:
CRISPR_Results |
Cluster assignment table output from the |
CRISPR_TS_Results |
Output from the |
data(depMapCRISPRscores_subset)
data(depMapXPR_subset)
data(depMapTissue_subset)
mtsGeneDep_ID_Results <- mts_GeneDepID(exprsMatrix=depMapXPR_subset[1:3,],
crisprMatrix=depMapCRISPRscores_subset[1:10,], cores=1, fcVal=0.1, pVal=0.25,
tissueMatrix=depMapTissue_subset)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.