| mts_Mutation | R Documentation |
MultiSEp detects mutations that are enriched in gene clusters (for example, from mRNA expression); providing insight into the genetic background relevant to candidate 'Achilles Heel' relationships suggested by analysis of the CRISPR screen and transcriptome data. A chi-squared test is performed for each gene to derive p-values for the enrichment of mutation classes across the gene expression clusters on a per-tissue basis.
mts_Mutation(resultList = resultList, mutMatrix = mutMatrix, tissueMatrix = tissueMatrix,
cores = cores, pVal = pVal)
resultList |
A result list object produced by the |
mutMatrix |
A mutation score matrix in gene by sample format, where row names correspond to genes and column names correspond to sample names. The value should be either 'WT' or a mutation detail (e.g. amino acid change or coding sequence change). |
tissueMatrix |
A data frame containing 2 columns where column 1 is the sample id and column 2 is the tissue id. |
pVal |
A p-value filter, the default is 0.01. |
cores |
The number of compute cores to use, the default is 1. |
A data frame containing the results of MultiSEp analysis of mutations by gene expression clusters, with the following columns:
mrna_gene |
Identifier for the genes or other molecular species provided in the resultList cluster object |
mutation_gene |
Identifier for the genes with mutation data |
tissue |
Description of the tissue evaluated |
chiSqPvalue |
p-value from chi-squared test, assessing the distribution of mutation classes across the clusters |
mutation_per_mode |
Total number of mutated samples in the clusters (modes) for the given mutation_gene. |
mts_mixModelCluster
data(depMapXPR_subset)
data(depMapMUT_subset)
data(depMapTissue_subset)
mixModelClusters <- mts_mixModelCluster(dataMatrix = depMapXPR_subset[1,])
multisepMut <- mts_Mutation(
resultList = mixModelClusters[1],
mutMatrix = depMapMUT_subset,
tissueMatrix = depMapTissue_subset,
pVal = 0.01
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.