View source: R/mts_crisprPartition.R
| mts_crisprPartition | R Documentation |
Partitions the CRISPR gene effect scores using the supplied threshold. For example a score of -0.5 is the default threshold, which aims to partition samples into 'lethal' (representative of cell death or stasis) and 'non-lethal' groups.
mts_crisprPartition(
dataMatrix,
NumSampleThreshold = 20,
partitionThreshold=-0.5,
verbose=FALSE,
cores)
dataMatrix |
CRISPR score matrix in gene by sample format, where row names correspond to genes and column names correspond to sample names. |
NumSampleThreshold |
The minimum number of samples in which a gene must have a CRISPR score for it to be retained; genes with scores in more than
|
partitionThreshold |
The score value used to split data into two partitions, default is -0.5. |
verbose |
Controls the production of reporting messages, default is |
cores |
The number of compute cores to use, default is 1. |
A list object for each gene in the dataMatrix object
Samples |
Sample identifiers. |
Values |
The analysed value for each sample, for example the gene effect chronos score. |
Cluster_Assignment |
The assigned cluster value for each sample. |
mts_patternDetection
data("depMapCRISPRscores_subset")
crisprClusters_thresholded <- mts_crisprPartition(
dataMatrix=depMapCRISPRscores_subset[1:5,], cores=1
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.