View source: R/mts_genepairsChunkGeneration.R
| mts_genepairsChunkGeneration | R Documentation |
.RData files containing subsets of gene pairsGenerates .RData files ('chunks') containing subsets of gene pairs. These
subsets are useful for MultiSEp applications in high-performance computing (HPC)
environments, where each file ('chunk') may be analysed by one task in an array job.
This function takes one or two list objects containing cluster assignments and
generates .RData files containing subsets of the full gene pair list.
Each file contains a portion of the gene pairs that can be processed independently,
enabling mts_patternDetection to run in parallel across array jobs.
This facilitates scalable analysis of large gene pair sets.
mts_genepairsChunkGeneration(
genepairs = NULL,
mixModelClusters1,
mixModelClusters2=NULL,
num_tasks,
output_dir = tempdir(),
cores
)
genepairs |
Optional. A data frame containing two columns of gene names.
If |
mixModelClusters1 |
A list object containing cluster assignments generated by |
mixModelClusters2 |
Optional. A second list object containing cluster assignments generated by
|
num_tasks |
The number of |
output_dir |
Directory where the |
cores |
Number of compute cores to use. Defaults to 1. |
Splits the gene pairs into num_tasks chunks and writes each to the output
directory as a ‘genepairs_chunk_<i>.RData’ file.
Returns a list of length num_tasks whose elements are each NULL.
mts_mixModelCluster,
mts_mixModelCluster_XPR,
mts_crisprPartition,
mts_formatMatrix,
mts_patternDetection
data(depMapXPR_subset)
mixModelClusters = mts_mixModelCluster_XPR(
dataMatrix = depMapXPR_subset[1:5,],
cores=1
)
# Using a custom output directory to save the .RData files (chunks)
# Here we write to a temporary directory for the example
output_dir <- tempdir()
# Generate Gene Pairs and Save to 3 Files
mts_genepairsChunkGeneration(
mixModelClusters1 = mixModelClusters,
num_tasks = 3,
output_dir = output_dir
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.