View source: R/mts_mixModelCluster_XPR.R
| mts_mixModelCluster_XPR | R Documentation |
Assigns samples into clusters by unsupervised analysis of continuous values for a given gene, flexibly capturing between two to five different sub-populations of samples. This function is designed for RNA-seq data but may be adapted to other data types. Each sample (for example, a cell line) is assigned a probability of belonging to each cluster. Filtering steps include ensuring a gene is present in an adequate number of samples with an expression value above the background.
mts_mixModelCluster_XPR(
dataMatrix,
GeneXPRthresh = 3.321928,
NumSampleThresh = 20,
cores
)
dataMatrix |
A gene expression matrix in gene by sample format, where row names correspond to genes and column names correspond to sample names. |
GeneXPRthresh |
A gene expression value that retains genes expressed in samples above that value. Defaults to 3.321928 which corresponds to log2 transformed data. A TPM value of 10 is recommended for non-log transformed data. |
NumSampleThresh |
Determines how many samples a gene should be expressed in, with the expression value specified by GeneXPRthresh. Defaults to 20 samples. |
cores |
The number of compute cores to use, default is 1. |
Gaussian mixture modelling with Expectation-Maximisation (EM) discovers clusters, or modes, where cardinality is determined by Bayesian Information Criterion regularisation. The method from Lubbock et al. 2013 [Nucleic Acids Research 41, W562-W568] was adapted for application to gene dependency prediction. Contiguous clusters are ensured and the ordering of clusters is taken from the value one standard deviation below the mean rather than the mean value. For example, occasionally there is overlap between clusters determined by EM such that the samples contained in one cluster encompass the range of values within a second cluster; hence samples from the first cluster are both below the minimum value and above the maximum value for any sample in the second cluster. Downstream analysis based upon the clusters, for example construction of contingency tables, assumes contiguous clusters and this property is ensured by assigning cluster boundaries with the average of minimum and maximum values from neighbouring clusters.
A list object for each gene (or molecular species e.g. proteoform) in the dataMatrix object
Samples |
Sample identifiers. |
Values |
The analysed value for each sample, for example from the input log2 gene expression value. |
Cluster_Assignment |
The assigned cluster value for each sample. |
Lubbock et al. (2013) TMA Navigator: network inference, patient stratification and survival analysis with tissue microarray data [Nucleic Acids Research 41, W562-W568] \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/nar/gkt529")}
mts_patternDetection,
mts_formatMatrix
data("depMapXPR_subset")
mixModelClusters <- mts_mixModelCluster_XPR(dataMatrix = depMapXPR_subset[1,])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.