View source: R/mts_pairwiseExpressionPlot.R
| mts_pairwiseExpressionPlot | R Documentation |
Produces a scatterplot of two selected genes on the x and y axis, the boundaries between MultiSEp clusters are shown as blue lines.
mts_pairwiseExpressionPlot(exprsMatrix, gene1, gene2)
exprsMatrix |
Log2 gene expression matrix in a gene by sample format where rownames are genes and the column names are samples. |
gene1 |
User specified gene 1. Must match a gene in the exprsMatrix. |
gene2 |
User specified gene 2. Must match a gene in the exprsMatrix. |
Produces a scatter plot (base R graphics) of the two genes' log2 expression, with mixture-model cluster boundaries drawn as reference lines.
data(depMapXPR_subset)
mts_pairwiseExpressionPlot(exprsMatrix = depMapXPR_subset, gene1 = "STX2", gene2="VRK2")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.