View source: R/mts_targetCoverageFromMutations.R
| mts_targetCoverageFromMutations | R Documentation |
This function predicts the therapeutic population coverage achieved by inhibiting
each gene in the supplied network of (predicted) synthetic lethal (SL) relationships.
A patient with inactivating mutations in partner genes of the candidate target gene is
predicted to benefit from inhibition of the target gene because the candidate SL relationship
implies that cell death will be caused by inactivation of both genes (one by mutation and one by chemical inhibition).
This function can take as input a dataframe of gene pairs (edgeData) or the output from the mts_Mutation() function, both cases also require mutation calls as input.
mts_targetCoverageFromMutations(
mutData,
edgeData,
rowNum = nrow(edgeData),
cores
)
mutData |
A mutation score matrix in gene by sample format, where rownames correspond to genes and colnames correspond to sample names.
The value should be either |
edgeData |
A dataframe of (predicted) synthetic lethal gene pairs (edges), where gene1 is in column1 and gene2 is in column2.
Alternatively, a data frame containing results from the |
rowNum |
The number of gene pairs from |
cores |
The number of compute cores to use. Defaults to 1. |
A data frame containing the following columns:
Gene |
Candidate drug target gene. |
NeighbourCount |
The number of network neighbours |
NumSamplesWithMutation |
Number of samples with mutation(s) in any of the neighbour genes. |
NeighbourMutationFrequency |
The proportion of samples with one or more mutations in any of the neighbour genes. |
NeighbourGenes |
Identifiers of the neighbouring genes. |
MutatedSamples |
Identifiers of the samples with mutations |
data(depMapMUT_subset)
data(mRes)
# An example on the first 5 edges (runs quickly):
TpopCoverage_test <- mts_targetCoverageFromMutations(
mutData=depMapMUT_subset,
edgeData=mRes,
rowNum=5,
cores=1
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.